pub struct MultiexpTable { /* private fields */ }Expand description
Precomputed table for performing faster multiexponentiation
Implementations
Sourceimpl MultiexpTable
impl MultiexpTable
Sourcepub fn build(
s: &Integer,
t: &Integer,
x_bits: u32,
y_bits: u32,
N: Integer,
) -> Option<Self>
pub fn build( s: &Integer, t: &Integer, x_bits: u32, y_bits: u32, N: Integer, ) -> Option<Self>
Builds a multiexponentiation table to perform s^x t^y mod N faster
where x and y are up to x_bits and y_bits
Returns None is s or t are non-positive or if any of them are not co-prime to N or
if N is less than 2.
Sourcepub fn prod_exp(&self, x: &Integer, y: &Integer) -> Option<Integer>
pub fn prod_exp(&self, x: &Integer, y: &Integer) -> Option<Integer>
Calculates s^x t^y mod N
Returns None if either x or y do not fit into x_bits or y_bits provided in MultiexpTable::build.
Sourcepub fn max_exponents_size(&self) -> (usize, usize)
pub fn max_exponents_size(&self) -> (usize, usize)
Returns max size of exponents (in bits) that can be computed
Max exponent size is guaranteed to be equal or greater than x_bits and y_bits
provided in MultiexpTable::build
Sourcepub fn size_in_bytes(&self) -> usize
pub fn size_in_bytes(&self) -> usize
Estimates size of the table in RAM in bytes